========
Examples
========

Here you will find some example notebooks to get more familiar with the API.


darts intro
===========

You will find below an example Jupyter notebook containing an intro to the usage of darts.

.. toctree::
   :maxdepth: 1

   examples/01-darts-intro.ipynb


Multiple Time Series, Pre-trained Models and Covariates
=======================================================

You will find below an example Jupyter notebook showcasing models trained on multiple time series, pre-trained models, and the usage of covariates.

.. toctree::
   :maxdepth: 1

   examples/02-multi-time-series-and-covariates.ipynb


Data (pre) Processing
=====================

You will find below an example Jupyter notebook showcasing the data processing abilities of darts.

.. toctree::
   :maxdepth: 1

   examples/03-data-processing.ipynb


Fast Fourier Transform
======================

You will find below an example Jupyter notebook showcasing the usage of the FFT model

.. toctree::
   :maxdepth: 1

   examples/04-FFT-examples.ipynb

Recurrent Neural Networks
=========================

You will find below an example Jupyter notebook showcasing the usage of the RNN model

.. toctree::
   :maxdepth: 1

   examples/05-RNN-examples.ipynb

Temporal Convolutional Networks
===============================

You will find below an example Jupyter notebook showcasing the usage of the TCN model

.. toctree::
   :maxdepth: 1

   examples/06-TCN-examples.ipynb

Transformer Model Examples
==========================

You will find below an example Jupyter notebook showcasing the usage of the Transformer model

.. toctree::
   :maxdepth: 1

   examples/07-Transformer-examples.ipynb

N-BEATS Model Examples
==========================

You will find below an example Jupyter notebook showcasing the usage of the N-BEATS model

.. toctree::
   :maxdepth: 1

   examples/08-NBEATS-examples.ipynb
